### R code from vignette source 'PloGO.Rnw'

###################################################
### code chunk number 1: library
###################################################
library(PloGO)
library(xtable)
ptm <- proc.time() # time how long it all takes


###################################################
### code chunk number 2: genFile
###################################################
v <- c("ENSP00000003100", "ENSP00000075120", "ENSP00000160262", "ENSP00000172229", "ENSP00000184956")
genWegoFile(v, fname = "F1.txt")
#
# uniprot biomaRt hangs
# v <- c("P38013", "Q04432", "P11986", "P22943", "P00360", "P10591", "P21147", "P07281", "P50263", "P00924", 
#	"P39676", "O43137", "P16521")
# genWegoFile(v, fname = "F1.txt", database = "uniprot")


###################################################
### code chunk number 3: PloGO.Rnw:103-104
###################################################
print(xtable(read.annot.file("F1.txt"), align = "rp{4cm}p{10cm}"))


###################################################
### code chunk number 4: PloGO.Rnw:110-116
###################################################
path <- system.file("files", package = "PloGO")
goRet <- file.path(path, "goRetOutput.txt")
print(xtable(read.annot.file(goRet)[1:10, ]))
bioMt <- file.path(path, "mart_export.txt")
print(xtable(read.annot.file(bioMt)[1:10, ]))



###################################################
### code chunk number 5: genFile
###################################################
file.names <- file.path(path, c("00100.txt", "01111.txt", "10000.txt", "11111.txt", "Control.txt"))
datafile <- file.path(path, "NSAFDesc.csv")


###################################################
### code chunk number 6: PloGO.Rnw:131-132
###################################################
options(width = 60)


###################################################
### code chunk number 7: GoLev3
###################################################
GOIDlist <- GOTermList("BP", level = 2)


###################################################
### code chunk number 8: GoSlim
###################################################
GOSlimCC <- c( "GO:0000228", "GO:0000229", "GO:0005575", "GO:0005576", "GO:0005578", "GO:0005615", "GO:0005618", "GO:0005622", "GO:0005623", "GO:0005634", "GO:0005635", "GO:0005654", "GO:0005694", "GO:0005730", "GO:0005737", "GO:0005739", "GO:0005764", "GO:0005768", "GO:0005773", "GO:0005777", "GO:0005783", "GO:0005794", "GO:0005811", "GO:0005815", "GO:0005829", "GO:0005840", "GO:0005856", "GO:0005886", "GO:0005929", "GO:0009536", "GO:0009579", "GO:0016023", "GO:0030312", "GO:0043226", "GO:0043234" )


###################################################
### code chunk number 9: GoIDlist
###################################################
# Extract a few categories of interest
termList <- c("response to stimulus", "transport", "protein folding","protein metabolic process", "carbohydrate metabolic process","oxidation reduction", "photosynthesis", "lipid metabolic process","cell redox homeostasis", "cellular amino acid and derivative metabolic process", "nucleobase, nucleoside and nucleotide metabolic process", "vitamin metabolic process", "generation of precursor metabolites and energy", "metabolic process", "signaling")
GOIDmap <- getGoID(termList)
GOIDlist <- names(GOIDmap)


###################################################
### code chunk number 10: processFile (eval = FALSE)
###################################################
## processGoFile("F1.txt", GOIDlist)


###################################################
### code chunk number 11: processFiles
###################################################
res.list <- processAnnotation(file.names, GOIDlist, printFiles = TRUE)


###################################################
### code chunk number 12: printAnnot
###################################################
annot.res <- annotationPlot(res.list)


###################################################
### code chunk number 13: PloGO.Rnw:179-182
###################################################
print(xtable(annot.res$counts, align = "rp{1.2cm}p{1.2cm}p{1.2cm}p{1.2cm}p{1.2cm}"))
print(xtable(annot.res$percentages, align = "rp{1.2cm}p{1.2cm}p{1.2cm}p{1.2cm}p{1.2cm}"))



###################################################
### code chunk number 14: PloGO.Rnw:201-203
###################################################
res <- compareAnnot(res.list, "Control")
print(xtable(res))


###################################################
### code chunk number 15: withAbundance
###################################################
res.list <- processAnnotation(file.names, GOIDlist, datafile = datafile, printFiles = TRUE, datafile.ignore.cols = 2)


###################################################
### code chunk number 16: withAbundance
###################################################
writeAnnotation(res.list, datafile = datafile, format = "matrix")


###################################################
### code chunk number 17: annotationPlot
###################################################
tp <- abundancePlot(res.list)
proc.time() - ptm # and how long it all took


